@@ -1,6 +1,6 @@
 package Mason::Filters::Standard;
 BEGIN {
-  $Mason::Filters::Standard::VERSION = '2.15';
+  $Mason::Filters::Standard::VERSION = '2.16';
 }
 use Mason::DynamicFilter;
 use Mason::Util;
@@ -97,7 +97,20 @@ Content|http://search.cpan.org/perldoc?HTML::Mason::Devel#Component_Calls_with_C
 
 =item NoBlankLines
 
-Remove lines with only whitespace from content.
+Remove lines with only whitespace from content. This
+
+    % $.NoBlankLines {{
+
+    hello
+
+
+    world    
+    % }}
+
+yields
+
+    hello
+    world
 
 =item Repeat ($count)
 
